==> Adsorber-1.1.tar.gz: Adsorber-1.1/README.md <==
# The Adsorber Program

[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/Adsorber)](https://docs.python.org/3/)
[![GitHub release (latest by date)](https://img.shields.io/github/v/release/GardenGroupUO/Adsorber)](https://github.com/GardenGroupUO/Adsorber)
[![PyPI](https://img.shields.io/pypi/v/Adsorber)](https://pypi.org/project/Adsorber/)
[![Conda](https://img.shields.io/conda/v/gardengroupuo/adsorber)](https://anaconda.org/GardenGroupUO/adsorber)
[![Documentation](https://img.shields.io/badge/Docs-click%20here-brightgreen)](https://adsorber.readthedocs.io/en/latest/)
[![Licence](https://img.shields.io/github/license/GardenGroupUO/Adsorber)](https://www.gnu.org/licenses/agpl-3.0.en.html)
[![LGTM Grade](https://img.shields.io/lgtm/grade/python/github/GardenGroupUO/Adsorber)](https://lgtm.com/projects/g/GardenGroupUO/Adsorber/context:python)

CURRENTLY UNDER RECONSTRUCTION: SOME FEATURES MAY NOT CURRENTLY BE WORKING

Authors: Geoffrey R. Weal and Dr. Anna L. Garden (University of Otago, Dunedin, New Zealand)

Group page: https://blogs.otago.ac.nz/annagarden/

## What is Adsorber

Adsorber is designed to adsorb molecules in various way to a cluster or surface. 

## Installation

It is recommended to read the installation page before using the Adsorber program. 

[adsorber.readthedocs.io/en/latest/Installation.html](https://adsorber.readthedocs.io/en/latest/Installation.html)

Note that you can install Adsorber through ``pip3`` and ``conda``. 

## Output files that are created by Adsorber

Adsorber will adsorb atoms and molecules on various binding sites across your cluster or surface model. An example of an COOH molecules adsorbed to a vertex site on a Cu<sub>78</sub> cluster is shown below

<p align="center">
	<img src="https://github.com/GardenGroupUO/Adsorber/blob/main/Documentation/source/Images/COOH_site_1_rotation_0.png">
</p>

## Where can I find the documentation for Adsorber

All the information about this program is found online at [adsorber.readthedocs.io/en/latest/](https://adsorber.readthedocs.io/en/latest/). Click the button below to also see the documentation: 

[![Documentation](https://img.shields.io/badge/Docs-click%20here-brightgreen)](https://adsorber.readthedocs.io/en/latest/)

## About

<div align="center">

| Python | [![PyPI - Python Version](https://img.shields.io/pypi/pyversions/Adsorber)](https://docs.python.org/3/) | 
|:----------------------:|:-------------------------------------------------------------:|
| Repositories | [![GitHub release (latest by date)](https://img.shields.io/github/v/release/GardenGroupUO/Adsorber)](https://github.com/GardenGroupUO/Adsorber) [![PyPI](https://img.shields.io/pypi/v/Adsorber)](https://pypi.org/project/Adsorber/) [![Conda](https://img.shields.io/conda/v/gardengroupuo/adsorber)](https://anaconda.org/GardenGroupUO/adsorber) |
| Documentation | [![Documentation](https://img.shields.io/badge/Docs-click%20here-brightgreen)](https://adsorber.readthedocs.io/en/latest/) | 
| Tests | [![LGTM Grade](https://img.shields.io/lgtm/grade/python/github/GardenGroupUO/Adsorber)](https://lgtm.com/projects/g/GardenGroupUO/Adsorber/context:python)
| License | [![Licence](https://img.shields.io/github/license/GardenGroupUO/Adsorber)](https://www.gnu.org/licenses/agpl-3.0.en.html) |
| Authors | Geoffrey R. Weal, Dr. Anna L. Garden |
| Group Website | https://blogs.otago.ac.nz/annagarden/ |

</div>

==> Adsorber-1.10.tar.gz: Adsorber-1.10/README.md <==

![Title_logo](Documentation/source/Images/icon_image/icon_drawing_github.png?raw=true "Logo")

# The Adsorber Program

[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/Adsorber)](https://docs.python.org/3/)
[![GitHub release (latest by date)](https://img.shields.io/github/v/release/GardenGroupUO/Adsorber)](https://github.com/GardenGroupUO/Adsorber)
[![PyPI](https://img.shields.io/pypi/v/Adsorber)](https://pypi.org/project/Adsorber/)
[![Conda](https://img.shields.io/conda/v/gardengroupuo/adsorber)](https://anaconda.org/GardenGroupUO/adsorber)
[![Documentation](https://img.shields.io/badge/Docs-click%20here-brightgreen)](https://adsorber.readthedocs.io/en/latest/)
[![Licence](https://img.shields.io/github/license/GardenGroupUO/Adsorber)](https://www.gnu.org/licenses/agpl-3.0.en.html)
[![LGTM Grade](https://img.shields.io/lgtm/grade/python/github/GardenGroupUO/Adsorber)](https://lgtm.com/projects/g/GardenGroupUO/Adsorber/context:python)

Authors: Dr. Geoffrey R. Weal and Dr. Anna L. Garden (University of Otago, Dunedin, New Zealand)

Group page: https://blogs.otago.ac.nz/annagarden/

## What is Adsorber

Adsorber is designed to create a number of models that have adsorbates adsorbed to various top, bridge, three-fold, and four-fold site on a cluster or surface model. 

## Installation

It is recommended to read the installation page before using the Adsorber program. 

[adsorber.readthedocs.io/en/latest/Installation.html](https://adsorber.readthedocs.io/en/latest/Installation.html)

Note that you can install Adsorber through ``pip3`` and ``conda``. 

Jmol is also used for looking at your cluster/surface model with adsorbed atoms and molecules upon it. You can see how to install and use it at [Installing and Using ASE GUI and Jmol](https://adsorber.readthedocs.io/en/latest/External_programs_that_will_be_useful_to_install_for_using_Adsorber.html). 

## Output files that are created by Adsorber

Adsorber will adsorb atoms and molecules on various binding sites across your cluster or surface model. These include top, bridge, three-fold, and four-fold sites. An example of an COOH molecules adsorbed to a corner top-site on a Cu<sub>78</sub> cluster is shown below

<p align="center">
	<img src="https://github.com/GardenGroupUO/Adsorber/blob/main/Documentation/source/Images/COOH_site_1_rotation_0.png">
</p>

## Where can I find the documentation for Adsorber

All the information about this program is found online at [adsorber.readthedocs.io/en/latest/](https://adsorber.readthedocs.io/en/latest/). Click the button below to also see the documentation: 

[![Documentation](https://img.shields.io/badge/Docs-click%20here-brightgreen)](https://adsorber.readthedocs.io/en/latest/)

## The ``Adsorber`` Program is a "work in progress"

This program is definitely a "work in progress". I have made it as easy to use as possible, but there are always oversights to program development and some parts of it may not be as easy to use as it could be. If you have any issues with the program or you think there would be better/easier ways to use and implement things in ``Adsorber``, feel free to email Geoffrey about these (geoffrey.weal@gmail.com). Feedback is very much welcome!

## About

<div align="center">

| Python | [![PyPI - Python Version](https://img.shields.io/pypi/pyversions/Adsorber)](https://docs.python.org/3/) | 
|:----------------------:|:-------------------------------------------------------------:|
| Repositories | [![GitHub release (latest by date)](https://img.shields.io/github/v/release/GardenGroupUO/Adsorber)](https://github.com/GardenGroupUO/Adsorber) [![PyPI](https://img.shields.io/pypi/v/Adsorber)](https://pypi.org/project/Adsorber/) [![Conda](https://img.shields.io/conda/v/gardengroupuo/adsorber)](https://anaconda.org/GardenGroupUO/adsorber) |
| Documentation | [![Documentation](https://img.shields.io/badge/Docs-click%20here-brightgreen)](https://adsorber.readthedocs.io/en/latest/) | 
| Tests | [![LGTM Grade](https://img.shields.io/lgtm/grade/python/github/GardenGroupUO/Adsorber)](https://lgtm.com/projects/g/GardenGroupUO/Adsorber/context:python)
| License | [![Licence](https://img.shields.io/github/license/GardenGroupUO/Adsorber)](https://www.gnu.org/licenses/agpl-3.0.en.html) |
| Authors | Geoffrey R. Weal, Dr. Anna L. Garden |
| Group Website | https://blogs.otago.ac.nz/annagarden/ |

</div>
